@@ -10,10 +10,19 @@ def search_semi_naive_LAM_window(diP, start_position, text, threshold):
     lengthSeqRef = len(text)
     score=0
     position_in_window = 0
+
+    #Check for character IUPAC
+    if text[start_position] not in diP.alphabet:
+        return None
     # Check at each position of the window
     for j in range(start_position, start_position + diP.length):
         d = text[j]
         b = text[j + 1]
+
+        #Check for character IUPAC
+        if b not in diP.alphabet:
+            return None
+
         score = score + diP.value[position_in_window][d + b]
         # print(j,score,score + diP.LAM[position_in_window + 1][b],diP.LAM[position_in_window + 1])
         # if partial score + estimate max score suffixe doesn't reach threshold : break
@@ -44,11 +53,19 @@ def search_semi_naive_LAM(diP, text, threshold):
     for i in range(0, lengthSeqRef - 1 - diP.length):
         score=0
         complete = False
+
+        #Check for character IUPAC
+        if text[i] not in diP.alphabet:
+            return None
         # Check at each position of the window
         for j in range(0, diP.length):
             d = text[i + j]
             b = text[i + j + 1]
 
+            #Check for character IUPAC
+            if b not in diP.alphabet:
+                return None
+
             # if partial score + estimate max score suffixe doesn't reach threshold : break
             if (j<diP.length - 1) and ((score + diP.value[j][d + b] + diP.LAM[j + 1][b]) < threshold):
                 score=(-math.inf)
@@ -105,11 +122,20 @@ def search_semi_naive_LAT(diP, text, threshold):
     for i in range(0,lengthSeqRef-1-diP.length):
         score=0
         complete = False
+
+        #Check for character IUPAC
+        if text[i] not in diP.alphabet:
+            return None
+
         # Check at each position of the window
         for j in range(0,diP.length):
             d=text[i+j]
             b=text[i+j+1]
 
+            #Check for character IUPAC
+            if b not in diP.alphabet:
+                return None
+
             # if partial score + estimate max score suffixe doesn't reach threshold : break
             if (j<diP.length-1) and ((score + diP.value[j][d + b] + LAT[j+1]) < threshold):
                 score=(-math.inf)
@@ -167,12 +193,22 @@ def search_semi_naive_back_LBM(diP, text, threshold):
     for i in range(diP.length, lengthSeqRef):
         score=0
         complete = False
+
+
+        #Check for character IUPAC
+        if text[i] not in diP.alphabet:
+            return None
+
         # Check at each position of the window, starting from the end of the window
         # moving backward
         for j in range(diP.length-2,-2,-1):
             d=text[i-(diP.length-1-j)]
             b=text[i-(diP.length-1-j)+1]
 
+            #Check for character IUPAC
+            if b not in diP.alphabet:
+                return None
+
             # if partial score + estimate max score prefix doesn't reach threshold : break
             if (j>0) and ((score + diP.value[j+1][d + b] + LBM[j][d]) < threshold):
                 score=(-math.inf)
@@ -231,12 +267,21 @@ def search_semi_naive_back_LBT(diP, text, threshold):
     for i in range(diP.length, lengthSeqRef):
         score=0
         complete = False
+
+        #Check for character IUPAC
+        if text[i] not in diP.alphabet:
+            return None
+
         # Check at each position of the window, starting from the end of the window
         # moving backward
         for j in range(diP.length-2,-2,-1):
             d=text[i-(diP.length-1-j)]
             b=text[i-(diP.length-1-j)+1]
 
+            #Check for character IUPAC
+            if b not in diP.alphabet:
+                return None
+
             # if partial score + estimate max score prefix doesn't reach threshold : break
             if (j>0) and ((score + diP.value[j+1][d + b] + LBT[j]) < threshold):
                 score=(-math.inf)
